from typing import Dict

DEBUG = False
LOG_LEVEL = 10
METRICS_ENABLE = False
EVENTS_METRIC_ENABLE = False
PROMETHEUS_METRICS_ENABLE = True
